@@ -64,7 +64,9 @@ class Google(Router):
             Example:
 
             >>> from routingpy.routers import Google
-            >>> router = Google(my_key, requests_kwargs={'proxies': {'https': '129.125.12.0'}})
+            >>> router = Google(my_key, requests_kwargs={
+            >>>     'proxies': {'https': '129.125.12.0'}
+            >>> })
             >>> print(router.proxies)
             {'https': '129.125.12.0'}
         :type requests_kwargs: dict
